package com.jiuqi.util.patterns;

import com.jiuqi.util.StringUtils;
import java.util.Map;

/* loaded from: com_jiuqi_util_patterns.jar:com/jiuqi/util/patterns/VariablePattern.class */
class VariablePattern implements IPattern {
    private String name;
    private int length;

    public void parse(String expression) throws PatternException {
        clear();
        if (expression == null) {
            return;
        }
        int p = expression.lastIndexOf(58);
        if (p == -1) {
            this.name = expression;
            this.length = 0;
            return;
        }
        this.name = expression.substring(0, p);
        String valStr = expression.substring(p + 1);
        if (StringUtils.isEmpty(valStr)) {
            this.length = 0;
            return;
        }
        try {
            this.length = Integer.parseInt(valStr);
        } catch (NumberFormatException e) {
            throw new PatternException(e);
        }
    }

    public String toString() {
        StringBuffer buffer = new StringBuffer("${");
        if (this.length == 0) {
            buffer.append(this.name);
        } else {
            buffer.append(this.name).append(':').append(this.length);
        }
        buffer.append('}');
        return buffer.toString();
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void add(IPattern pattern) {
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void add(int index, IPattern pattern) {
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void clear() {
        this.name = null;
        this.length = 0;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public IPattern get(int index) {
        return null;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public String getExpression() {
        return this.name;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int getLength() {
        return this.length;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int getType() {
        return 1;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int indexOf(IPattern pattern) {
        return -1;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void remove(int index) {
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void setExpression(String value) {
        try {
            parse(value);
        } catch (PatternException unused) {
            clear();
        }
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public void setLength(int value) {
        this.length = value;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int size() {
        return 0;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public int match(String s, int start, Map values) {
        if (this.length == 0 || start + this.length > s.length()) {
            return -1;
        }
        return start + this.length;
    }

    @Override // com.jiuqi.util.patterns.IPattern
    public String replace(ITranslator translator) {
        String[] ret = translator.translate(this.name, this.length);
        if (ret == null) {
            return toString();
        }
        return ret.length == 0 ? "" : ret[0];
    }
}
